@@ -15,6 +15,9 @@ mobileDetect <-
 
 shinyUI(
   fluidPage(
+    tags$div(tags$br()),
+    downloadButton("download_code", tags$strong("Download code")),
+    tags$div(tags$br()),
     tags$head(includeCSS("www/style.css")),
     tags$head(includeScript("www/js/tag-manager.js")),
     mobileDetect("isMobile"),
@@ -72,12 +75,12 @@ shinyUI(
         "Download",
         icon = icon("download", lib = "font-awesome"),
         fluidRow(downloadButton("download", "Download all data"))
-      ),
-      tabPanel(
-        "About",
-        icon = icon("info-circle", lib = "font-awesome"),
-        fluidRow(includeMarkdown("www/about.Rmd"))
       )
+      # tabPanel(
+      #   "About",
+      #   icon = icon("info-circle", lib = "font-awesome"),
+      #   fluidRow(includeMarkdown("www/about.Rmd"))
+      # )
     )
   )
 )
